==> ulyxex.1.2.2.alone.zip: pages/core/admin_article_modify.php <==
<?php
/* Ulyxex version 1.2.2 *****************/
class ArticleModify extends Admin {
	function __construct($artId=Null){
		$this->h = New Html();
		$this->t = New Translate();
		$this->tree = New Tree();
		$this->article_id = $artId;
		$this->Select = 	" SELECT ".
										ARTICLES.".*,".
										USERS.".USERNAME,".USERS.".ID IDUSERID,".USERS.".USERLEVEL,".
										PAGES.".NAME,".PAGES.".ID PAGEID,".PAGES.".USERID USERPAGEID";
		$this->From = 		" FROM ".
										ARTICLES.
										" INNER JOIN ".PAGES. " ON ".ARTICLES.".PAGEID = ".PAGES.".ID".
										" INNER JOIN ".USERS." ON ".ARTICLES.".USERID = ".USERS.".ID";
		$this->Cond = array();
	}
	public function update_article(){
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$content = $this->h->safe($_POST['content']);
		$pageId = isset($_POST['parent'])?$this->h->num($_POST['parent']):2; // 2 = sandbox id
		$query = "UPDATE ".ARTICLES."  SET SUBJECT = '".$this->h->safe($_POST['subject'])."'";
		if (isset($_POST['userid']) && $_POST['userid'] != $_POST['old_userid']) $query .=	",USERID = ".$this->h->num($_POST['userid']); // change userId
		$query .= isset($_POST['updateDate'])?",DATEPAGE = '".$date."'":"";
		$query .=						",CONTENT = '".$content."'".
										",HIDE = ".$hide.
										",PAGEID = ".$pageId.
										" WHERE ID = ".$this->article_id;
		$query = $this->q($query);
		return $this->h->h3("article ".strip_tags($_POST['subject'])." updated !","class='warning'");
	}
	public function data_article(){
		$h = $this->h;$t = $this->t;
		switch ($_SESSION['level']){
			case 1:
				// user level 1 can't edit others user level 1
				if ($_SESSION['userid'] != 1){ // admin edit all
					$this->Cond[] = "(".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's articles, user's articles 
					$this->Cond[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->Cond[] = ARTICLES.".ID = ".$this->article_id;
				break;
			case 2:
				$this->Cond[] = "(".USERS.".ID = ".$_SESSION['userid']." OR ".PAGES.".USERID = ".$_SESSION['userid'].")"; // user's articles and articles in user's pages
				$this->Cond[] = USERS.".ID != 1"; // but not admin articles
				$this->Cond[] = ARTICLES.".ID = ".$this->article_id;
				break;
			default:
				$this->Cond[] = ARTICLES.".USERID = ".$_SESSION['userid']; // user's articles only
				$this->Cond[] = ARTICLES.".ID = ".$this->article_id;
		}
		$query = $this->Select.$this->From.$this->Where($this->Cond);
		$query = $this->q($query);
		if ($dat = $this->fetch($query)){
			$_[] = $h->input("hidden","update",1);
			$_[] = $h->input("hidden","art",$dat['ID']);
			$_[] = ($_SESSION['level'] <= 3)?$h->p($t->wr("choose page").$this->tree->pathsSelect($dat['PAGEID'],0,"page")):$h->p("page: SandBox").$h->input("hidden","pageid",2); // 2 = sandbox id
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$_[] = $h->h3($t->wr("hide").$h->input("checkbox","hide","on",$params).$t->wlr("article content")."(id:".$dat['ID'].")");
			$_[] = ($_SESSION['level'] == 1)?$h->input("hidden","old_userid",$dat['USERID']).$h->p($t->wr("choose user").$this->array_users($dat['USERID'])):Null;
			$_[] = $h->p($t->w("subject (management only)")).$h->p($h->input("text","subject",$h->uly_htmlentities($dat['SUBJECT']),"size=".FIELDWIDTH));
			$_[] = $h->p($h->span("&lt;article&gt; ","class='tag'")."[".$h->ahref("admin.php?action=list_files",$t->w("list files"),"target='_blank'")."]");
			$_[] = $h->p($h->textarea($dat['CONTENT'],"content",array(12,FIELDWIDTH)));
			$_[] = $h->p($h->span("&lt;/article&gt; ","class='tag'").$t->wr("update date")."(".$dat['DATEPAGE'].") ".$h->input("checkbox","updateDate","1"));
			$_[] = $h->p($h->input("submit","save",$t->w("update")));
			$inputs = implode("",$_);
			return $h->form($inputs,"article","post","admin.php?action=modify_article");
		} else {
			return $h->p("error article data ");
		}
	}
}
?>

==> ulyxex.1.2.3.alone.zip: pages/core/admin_article_modify.php <==
<?php
/* Ulyxex version 1.2.3 *****************/
class ArticleModify extends Admin {
	function __construct($artId=Null){
		$this->h = New Html();
		$this->t = New Translate();
		$this->tree = New Tree();
		$this->article_id = $artId;
		$this->Select = 	SELECT.
									ARTICLES.".*,".
									USERS.".USERNAME,".USERS.".ID IDUSERID,".USERS.".USERLEVEL,".
									PAGES.".NAME,".PAGES.".ID PAGEID,".PAGES.".USERID USERPAGEID";
		$this->From = 		FROM.
									ARTICLES.
									INNERJOIN.PAGES._ON_.ARTICLES.".PAGEID = ".PAGES.".ID".
									INNERJOIN.USERS._ON_.ARTICLES.".USERID = ".USERS.".ID";
		$this->Cond = array();
	}
	public function update_article(){
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$content = $this->h->safe($_POST['content']);
		$pageId = isset($_POST['parent'])?$this->h->num($_POST['parent']):2; // 2 = sandbox id
		$query = UPDATE.ARTICLES.SET."SUBJECT = '".$this->h->safe($_POST['subject'])."'";
		if (isset($_POST['userid']) && $_POST['userid'] != $_POST['old_userid']) $query .=	",USERID = ".$this->h->num($_POST['userid']); // change userId
		$query .= isset($_POST['updateDate'])?",DATEPAGE = '".$date."'":"";
		$query .=					",CONTENT = '".$content."'".
									",HIDE = ".$hide.
									",PAGEID = ".$pageId.
									WHERE."ID = ".$this->article_id;
		$query = $this->q($query);
		return $this->h->h3("article ".strip_tags($_POST['subject'])." updated !","class='warning'");
	}
	public function data_article(){
		$h = $this->h;$t = $this->t;
		switch ($_SESSION['level']){
			case 1:
				// user level 1 can't edit others user level 1
				if ($_SESSION['userid'] != 1){ // admin edit all
					$this->Cond[] = "(".USERS.".USERLEVEL > ".$_SESSION['level']._OR_.USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's articles, user's articles 
					$this->Cond[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->Cond[] = ARTICLES.".ID = ".$this->article_id;
				break;
			case 2:
				$this->Cond[] = "(".USERS.".ID = ".$_SESSION['userid']._OR_.PAGES.".USERID = ".$_SESSION['userid'].")"; // user's articles and articles in user's pages
				$this->Cond[] = USERS.".ID != 1"; // but not admin articles
				$this->Cond[] = ARTICLES.".ID = ".$this->article_id;
				break;
			default:
				$this->Cond[] = ARTICLES.".USERID = ".$_SESSION['userid']; // user's articles only
				$this->Cond[] = ARTICLES.".ID = ".$this->article_id;
		}
		$query = $this->Select.$this->From.$this->Where($this->Cond);
		$query = $this->q($query);
		if ($dat = $this->fetch($query)){
			$_[] = $h->input("hidden","update",1);
			$_[] = $h->input("hidden","art",$dat['ID']);
			$_[] = ($_SESSION['level'] <= 3)?$h->p($t->wr("choose page").$this->tree->pathsSelect($dat['PAGEID'],0,"page")):$h->p("page: SandBox").$h->input("hidden","pageid",2); // 2 = sandbox id
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$_[] = $h->h3($t->wr("hide").$h->input("checkbox","hide","on",$params).$t->wlr("article content")."(id:".$dat['ID'].")");
			$_[] = ($_SESSION['level'] == 1)?$h->input("hidden","old_userid",$dat['USERID']).$h->p($t->wr("choose user").$this->array_users($dat['USERID'])):Null;
			$_[] = $h->p($t->w("subject (management only)")).$h->p($h->input("text","subject",$h->uly_htmlentities($dat['SUBJECT']),"size=".FIELDWIDTH));
			$_[] = $h->p($h->span("&lt;article&gt; ","class='tag'")."[".$h->ahref("admin.php?action=list_files",$t->w("list files"),"target='_blank'")."]");
			$_[] = $h->p($h->textarea($dat['CONTENT'],"content",array(12,FIELDWIDTH)));
			$_[] = $h->p($h->span("&lt;/article&gt; ","class='tag'").$t->wr("update date")."(".$dat['DATEPAGE'].") ".$h->input("checkbox","updateDate","1"));
			$_[] = $h->p($h->input("submit","save",$t->w("update")));
			$inputs = implode("",$_);
			return $h->form($inputs,"article","post","admin.php?action=modify_article");
		} else {
			return $h->p("error article data ");
		}
	}
}
?>
